fn halve_mod_p(a: FieldElement) -> FieldElementExpand description
Halves a field element modulo p.
Computes a / 2 mod p. If a is odd, adds p first to make
it even, then shifts right.
fn halve_mod_p(a: FieldElement) -> FieldElementHalves a field element modulo p.
Computes a / 2 mod p. If a is odd, adds p first to make
it even, then shifts right.